/*
 * Copyright 2019 Mike Penz
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.mikepenz.iconics.typeface.library.materialdesigndx

import com.mikepenz.iconics.typeface.IIcon
import com.mikepenz.iconics.typeface.ITypeface
import java.util.LinkedList

@Suppress("EnumEntryName")
object MaterialDesignDx : ITypeface {

    override val fontRes: Int
        get() = R.font.material_design_dx_font_v5_0_1

    override val characters: Map<String, Char> by lazy {
        Icon.values().associate { it.name to it.character }
    }

    override val mappingPrefix: String
        get() = "gmf"

    override val fontName: String
        get() = "Material Design DX"

    override val version: String
        get() = "5.0.1"

    override val iconCount: Int
        get() = characters.size

    override val icons: List<String>
        get() = characters.keys.toCollection(LinkedList())

    override val author: String
        get() = "Jossef Harush"

    override val url: String
        get() = "https://github.com/jossef/material-design-icons-iconfont"

    override val description: String
        get() = "MDIDX - Same Material Design icons, Better DX"

    override val license: String
        get() = "Apache 2.0"

    override val licenseUrl: String
        get() = "https://www.apache.org/licenses/LICENSE-2.0"

    override fun getIcon(key: String): IIcon = Icon.valueOf(key)

    enum class Icon constructor(override val character: Char) : IIcon {
        gmf_10k('\ue951'),
        gmf_10mp('\ue952'),
        gmf_11mp('\ue953'),
        gmf_12mp('\ue954'),
        gmf_13mp('\ue955'),
        gmf_14mp('\ue956'),
        gmf_15mp('\ue957'),
        gmf_16mp('\ue958'),
        gmf_17mp('\ue959'),
        gmf_18mp('\ue95a'),
        gmf_19mp('\ue95b'),
        gmf_1k('\ue95c'),
        gmf_1k_plus('\ue95d'),
        gmf_20mp('\ue95e'),
        gmf_21mp('\ue95f'),
        gmf_22mp('\ue960'),
        gmf_23mp('\ue961'),
        gmf_24mp('\ue962'),
        gmf_2k('\ue963'),
        gmf_2k_plus('\ue964'),
        gmf_2mp('\ue965'),
        gmf_360('\ue577'),
        gmf_3d_rotation('\ue84d'),
        gmf_3k('\ue966'),
        gmf_3k_plus('\ue967'),
        gmf_3mp('\ue968'),
        gmf_4k('\ue072'),
        gmf_4k_plus('\ue969'),
        gmf_4mp('\ue96a'),
        gmf_5k('\ue96b'),
        gmf_5k_plus('\ue96c'),
        gmf_5mp('\ue96d'),
        gmf_6k('\ue96e'),
        gmf_6k_plus('\ue96f'),
        gmf_6mp('\ue970'),
        gmf_7k('\ue971'),
        gmf_7k_plus('\ue972'),
        gmf_7mp('\ue973'),
        gmf_8k('\ue974'),
        gmf_8k_plus('\ue975'),
        gmf_8mp('\ue976'),
        gmf_9k('\ue977'),
        gmf_9k_plus('\ue978'),
        gmf_9mp('\ue979'),
        gmf_ac_unit('\ueb3b'),
        gmf_access_alarm('\ue190'),
        gmf_access_alarms('\ue191'),
        gmf_access_time('\ue192'),
        gmf_accessibility('\ue84e'),
        gmf_accessibility_new('\ue92c'),
        gmf_accessible('\ue914'),
        gmf_accessible_forward('\ue934'),
        gmf_account_balance('\ue84f'),
        gmf_account_balance_wallet('\ue850'),
        gmf_account_box('\ue851'),
        gmf_account_circle('\ue853'),
        gmf_account_tree('\ue97a'),
        gmf_adb('\ue60e'),
        gmf_add('\ue145'),
        gmf_add_a_photo('\ue439'),
        gmf_add_alarm('\ue193'),
        gmf_add_alert('\ue003'),
        gmf_add_box('\ue146'),
        gmf_add_call('\ue0e8'),
        gmf_add_chart('\ue97b'),
        gmf_add_circle('\ue147'),
        gmf_add_circle_outline('\ue148'),
        gmf_add_comment('\ue266'),
        gmf_add_ic_call('\ue97c'),
        gmf_add_link('\ue178'),
        gmf_add_location('\ue567'),
        gmf_add_moderator('\ue97d'),
        gmf_add_photo_alternate('\ue43e'),
        gmf_add_shopping_cart('\ue854'),
        gmf_add_to_home_screen('\ue1fe'),
        gmf_add_to_photos('\ue39d'),
        gmf_add_to_queue('\ue05c'),
        gmf_adjust('\ue39e'),
        gmf_airline_seat_flat('\ue630'),
        gmf_airline_seat_flat_angled('\ue631'),
        gmf_airline_seat_individual_suite('\ue632'),
        gmf_airline_seat_legroom_extra('\ue633'),
        gmf_airline_seat_legroom_normal('\ue634'),
        gmf_airline_seat_legroom_reduced('\ue635'),
        gmf_airline_seat_recline_extra('\ue636'),
        gmf_airline_seat_recline_normal('\ue637'),
        gmf_airplanemode_active('\ue195'),
        gmf_airplanemode_inactive('\ue194'),
        gmf_airplanemode_off('\ue194'),
        gmf_airplanemode_on('\ue195'),
        gmf_airplay('\ue055'),
        gmf_airport_shuttle('\ueb3c'),
        gmf_alarm('\ue855'),
        gmf_alarm_add('\ue856'),
        gmf_alarm_off('\ue857'),
        gmf_alarm_on('\ue858'),
        gmf_album('\ue019'),
        gmf_all_inbox('\ue97f'),
        gmf_all_inclusive('\ueb3d'),
        gmf_all_out('\ue90b'),
        gmf_alternate_email('\ue0e6'),
        gmf_amp_stories('\uea13'),
        gmf_android('\ue859'),
        gmf_announcement('\ue85a'),
        gmf_apartment('\uea40'),
        gmf_approval('\ue982'),
        gmf_apps('\ue5c3'),
        gmf_archive('\ue149'),
        gmf_arrow_back('\ue5c4'),
        gmf_arrow_back_ios('\ue5e0'),
        gmf_arrow_downward('\ue5db'),
        gmf_arrow_drop_down('\ue5c5'),
        gmf_arrow_drop_down_circle('\ue5c6'),
        gmf_arrow_drop_up('\ue5c7'),
        gmf_arrow_forward('\ue5c8'),
        gmf_arrow_forward_ios('\ue5e1'),
        gmf_arrow_left('\ue5de'),
        gmf_arrow_right('\ue5df'),
        gmf_arrow_right_alt('\ue941'),
        gmf_arrow_upward('\ue5d8'),
        gmf_art_track('\ue060'),
        gmf_aspect_ratio('\ue85b'),
        gmf_assessment('\ue85c'),
        gmf_assignment('\ue85d'),
        gmf_assignment_ind('\ue85e'),
        gmf_assignment_late('\ue85f'),
        gmf_assignment_return('\ue860'),
        gmf_assignment_returned('\ue861'),
        gmf_assignment_turned_in('\ue862'),
        gmf_assistant('\ue39f'),
        gmf_assistant_direction('\ue988'),
        gmf_assistant_navigation('\ue989'),
        gmf_assistant_photo('\ue3a0'),
        gmf_atm('\ue573'),
        gmf_attach_file('\ue226'),
        gmf_attach_money('\ue227'),
        gmf_attachment('\ue2bc'),
        gmf_attractions('\uea52'),
        gmf_audiotrack('\ue3a1'),
        gmf_autorenew('\ue863'),
        gmf_av_timer('\ue01b'),
        gmf_backspace('\ue14a'),
        gmf_backup('\ue864'),
        gmf_badge('\uea67'),
        gmf_bakery_dining('\uea53'),
        gmf_ballot('\ue172'),
        gmf_bar_chart('\ue26b'),
        gmf_bathtub('\uea41'),
        gmf_battery_alert('\ue19c'),
        gmf_battery_charging_full('\ue1a3'),
        gmf_battery_full('\ue1a4'),
        gmf_battery_std('\ue1a5'),
        gmf_battery_unknown('\ue1a6'),
        gmf_beach_access('\ueb3e'),
        gmf_beenhere('\ue52d'),
        gmf_block('\ue14b'),
        gmf_bluetooth('\ue1a7'),
        gmf_bluetooth_audio('\ue60f'),
        gmf_bluetooth_connected('\ue1a8'),
        gmf_bluetooth_disabled('\ue1a9'),
        gmf_bluetooth_searching('\ue1aa'),
        gmf_blur_circular('\ue3a2'),
        gmf_blur_linear('\ue3a3'),
        gmf_blur_off('\ue3a4'),
        gmf_blur_on('\ue3a5'),
        gmf_bolt('\uea0b'),
        gmf_book('\ue865'),
        gmf_bookmark('\ue866'),
        gmf_bookmark_border('\ue867'),
        gmf_bookmark_outline('\ue867'),
        gmf_bookmarks('\ue98b'),
        gmf_border_all('\ue228'),
        gmf_border_bottom('\ue229'),
        gmf_border_clear('\ue22a'),
        gmf_border_color('\ue22b'),
        gmf_border_horizontal('\ue22c'),
        gmf_border_inner('\ue22d'),
        gmf_border_left('\ue22e'),
        gmf_border_outer('\ue22f'),
        gmf_border_right('\ue230'),
        gmf_border_style('\ue231'),
        gmf_border_top('\ue232'),
        gmf_border_vertical('\ue233'),
        gmf_branding_watermark('\ue06b'),
        gmf_breakfast_dining('\uea54'),
        gmf_brightness_1('\ue3a6'),
        gmf_brightness_2('\ue3a7'),
        gmf_brightness_3('\ue3a8'),
        gmf_brightness_4('\ue3a9'),
        gmf_brightness_5('\ue3aa'),
        gmf_brightness_6('\ue3ab'),
        gmf_brightness_7('\ue3ac'),
        gmf_brightness_auto('\ue1ab'),
        gmf_brightness_high('\ue1ac'),
        gmf_brightness_low('\ue1ad'),
        gmf_brightness_medium('\ue1ae'),
        gmf_broken_image('\ue3ad'),
        gmf_brunch_dining('\uea73'),
        gmf_brush('\ue3ae'),
        gmf_bubble_chart('\ue6dd'),
        gmf_bug_report('\ue868'),
        gmf_build('\ue869'),
        gmf_burst_mode('\ue43c'),
        gmf_bus_alert('\ue98f'),
        gmf_business('\ue0af'),
        gmf_business_center('\ueb3f'),
        gmf_cached('\ue86a'),
        gmf_cake('\ue7e9'),
        gmf_calendar_today('\ue935'),
        gmf_calendar_view_day('\ue936'),
        gmf_call('\ue0b0'),
        gmf_call_end('\ue0b1'),
        gmf_call_made('\ue0b2'),
        gmf_call_merge('\ue0b3'),
        gmf_call_missed('\ue0b4'),
        gmf_call_missed_outgoing('\ue0e4'),
        gmf_call_received('\ue0b5'),
        gmf_call_split('\ue0b6'),
        gmf_call_to_action('\ue06c'),
        gmf_camera('\ue3af'),
        gmf_camera_alt('\ue3b0'),
        gmf_camera_enhance('\ue8fc'),
        gmf_camera_front('\ue3b1'),
        gmf_camera_rear('\ue3b2'),
        gmf_camera_roll('\ue3b3'),
        gmf_cancel('\ue5c9'),
        gmf_cancel_presentation('\ue0e9'),
        gmf_cancel_schedule_send('\uea39'),
        gmf_car_rental('\uea55'),
        gmf_car_repair('\uea56'),
        gmf_card_giftcard('\ue8f6'),
        gmf_card_membership('\ue8f7'),
        gmf_card_travel('\ue8f8'),
        gmf_cases('\ue992'),
        gmf_casino('\ueb40'),
        gmf_cast('\ue307'),
        gmf_cast_connected('\ue308'),
        gmf_category('\ue574'),
        gmf_celebration('\uea65'),
        gmf_cell_wifi('\ue0ec'),
        gmf_center_focus_strong('\ue3b4'),
        gmf_center_focus_weak('\ue3b5'),
        gmf_change_history('\ue86b'),
        gmf_chat('\ue0b7'),
        gmf_chat_bubble('\ue0ca'),
        gmf_chat_bubble_outline('\ue0cb'),
        gmf_check('\ue5ca'),
        gmf_check_box('\ue834'),
        gmf_check_box_outline_blank('\ue835'),
        gmf_check_circle('\ue86c'),
        gmf_check_circle_outline('\ue92d'),
        gmf_chevron_left('\ue5cb'),
        gmf_chevron_right('\ue5cc'),
        gmf_child_care('\ueb41'),
        gmf_child_friendly('\ueb42'),
        gmf_chrome_reader_mode('\ue86d'),
        gmf_circle_notifications('\ue994'),
        gmf_class('\ue86e'),
        gmf_clear('\ue14c'),
        gmf_clear_all('\ue0b8'),
        gmf_close('\ue5cd'),
        gmf_closed_caption('\ue01c'),
        gmf_closed_caption_off('\ue996'),
        gmf_cloud('\ue2bd'),
        gmf_cloud_circle('\ue2be'),
        gmf_cloud_done('\ue2bf'),
        gmf_cloud_download('\ue2c0'),
        gmf_cloud_off('\ue2c1'),
        gmf_cloud_queue('\ue2c2'),
        gmf_cloud_upload('\ue2c3'),
        gmf_code('\ue86f'),
        gmf_collections('\ue3b6'),
        gmf_collections_bookmark('\ue431'),
        gmf_color_lens('\ue3b7'),
        gmf_colorize('\ue3b8'),
        gmf_comment('\ue0b9'),
        gmf_commute('\ue940'),
        gmf_compare('\ue3b9'),
        gmf_compare_arrows('\ue915'),
        gmf_compass_calibration('\ue57c'),
        gmf_compress('\ue94d'),
        gmf_computer('\ue30a'),
        gmf_confirmation_num('\ue638'),
        gmf_confirmation_number('\ue638'),
        gmf_connected_tv('\ue998'),
        gmf_contact_mail('\ue0d0'),
        gmf_contact_phone('\ue0cf'),
        gmf_contact_support('\ue94c'),
        gmf_contactless('\uea71'),
        gmf_contacts('\ue0ba'),
        gmf_content_copy('\ue14d'),
        gmf_content_cut('\ue14e'),
        gmf_content_paste('\ue14f'),
        gmf_control_camera('\ue074'),
        gmf_control_point('\ue3ba'),
        gmf_control_point_duplicate('\ue3bb'),
        gmf_copyright('\ue90c'),
        gmf_create('\ue150'),
        gmf_create_new_folder('\ue2cc'),
        gmf_credit_card('\ue870'),
        gmf_crop('\ue3be'),
        gmf_crop_16_9('\ue3bc'),
        gmf_crop_3_2('\ue3bd'),
        gmf_crop_5_4('\ue3bf'),
        gmf_crop_7_5('\ue3c0'),
        gmf_crop_din('\ue3c1'),
        gmf_crop_free('\ue3c2'),
        gmf_crop_landscape('\ue3c3'),
        gmf_crop_original('\ue3c4'),
        gmf_crop_portrait('\ue3c5'),
        gmf_crop_rotate('\ue437'),
        gmf_crop_square('\ue3c6'),
        gmf_dangerous('\ue99a'),
        gmf_dashboard('\ue871'),
        gmf_dashboard_customize('\ue99b'),
        gmf_data_usage('\ue1af'),
        gmf_date_range('\ue916'),
        gmf_deck('\uea42'),
        gmf_dehaze('\ue3c7'),
        gmf_delete('\ue872'),
        gmf_delete_forever('\ue92b'),
        gmf_delete_outline('\ue92e'),
        gmf_delete_sweep('\ue16c'),
        gmf_delivery_dining('\uea72'),
        gmf_departure_board('\ue576'),
        gmf_description('\ue873'),
        gmf_desktop_access_disabled('\ue99d'),
        gmf_desktop_mac('\ue30b'),
        gmf_desktop_windows('\ue30c'),
        gmf_details('\ue3c8'),
        gmf_developer_board('\ue30d'),
        gmf_developer_mode('\ue1b0'),
        gmf_device_hub('\ue335'),
        gmf_device_thermostat('\ue1ff'),
        gmf_device_unknown('\ue339'),
        gmf_devices('\ue1b1'),
        gmf_devices_other('\ue337'),
        gmf_dialer_sip('\ue0bb'),
        gmf_dialpad('\ue0bc'),
        gmf_dinner_dining('\uea57'),
        gmf_directions('\ue52e'),
        gmf_directions_bike('\ue52f'),
        gmf_directions_boat('\ue532'),
        gmf_directions_bus('\ue530'),
        gmf_directions_car('\ue531'),
        gmf_directions_ferry('\ue532'),
        gmf_directions_railway('\ue534'),
        gmf_directions_run('\ue566'),
        gmf_directions_subway('\ue533'),
        gmf_directions_train('\ue534'),
        gmf_directions_transit('\ue535'),
        gmf_directions_walk('\ue536'),
        gmf_disc_full('\ue610'),
        gmf_dnd_forwardslash('\ue611'),
        gmf_dns('\ue875'),
        gmf_do_not_disturb('\ue612'),
        gmf_do_not_disturb_alt('\ue611'),
        gmf_do_not_disturb_off('\ue643'),
        gmf_do_not_disturb_on('\ue644'),
        gmf_dock('\ue30e'),
        gmf_domain('\ue7ee'),
        gmf_domain_disabled('\ue0ef'),
        gmf_done('\ue876'),
        gmf_done_all('\ue877'),
        gmf_done_outline('\ue92f'),
        gmf_donut_large('\ue917'),
        gmf_donut_small('\ue918'),
        gmf_double_arrow('\uea50'),
        gmf_drafts('\ue151'),
        gmf_drag_handle('\ue25d'),
        gmf_drag_indicator('\ue945'),
        gmf_drive_eta('\ue613'),
        gmf_drive_file_move_outline('\ue9a1'),
        gmf_drive_file_rename_outline('\ue9a2'),
        gmf_drive_folder_upload('\ue9a3'),
        gmf_dry_cleaning('\uea58'),
        gmf_duo('\ue9a5'),
        gmf_dvr('\ue1b2'),
        gmf_dynamic_feed('\uea14'),
        gmf_eco('\uea35'),
        gmf_edit('\ue3c9'),
        gmf_edit_attributes('\ue578'),
        gmf_edit_location('\ue568'),
        gmf_edit_off('\ue950'),
        gmf_eject('\ue8fb'),
        gmf_email('\ue0be'),
        gmf_emoji_emotions('\uea22'),
        gmf_emoji_events('\uea23'),
        gmf_emoji_flags('\uea1a'),
        gmf_emoji_food_beverage('\uea1b'),
        gmf_emoji_nature('\uea1c'),
        gmf_emoji_objects('\uea24'),
        gmf_emoji_people('\uea1d'),
        gmf_emoji_symbols('\uea1e'),
        gmf_emoji_transportation('\uea1f'),
        gmf_enhance_photo_translate('\ue8fc'),
        gmf_enhanced_encryption('\ue63f'),
        gmf_equalizer('\ue01d'),
        gmf_error('\ue000'),
        gmf_error_outline('\ue001'),
        gmf_euro('\uea15'),
        gmf_euro_symbol('\ue926'),
        gmf_ev_station('\ue56d'),
        gmf_event('\ue878'),
        gmf_event_available('\ue614'),
        gmf_event_busy('\ue615'),
        gmf_event_note('\ue616'),
        gmf_event_seat('\ue903'),
        gmf_exit_to_app('\ue879'),
        gmf_expand('\ue94f'),
        gmf_expand_less('\ue5ce'),
        gmf_expand_more('\ue5cf'),
        gmf_explicit('\ue01e'),
        gmf_explore('\ue87a'),
        gmf_explore_off('\ue9a8'),
        gmf_exposure('\ue3ca'),
        gmf_exposure_minus_1('\ue3cb'),
        gmf_exposure_minus_2('\ue3cc'),
        gmf_exposure_neg_1('\ue3cb'),
        gmf_exposure_neg_2('\ue3cc'),
        gmf_exposure_plus_1('\ue3cd'),
        gmf_exposure_plus_2('\ue3ce'),
        gmf_exposure_zero('\ue3cf'),
        gmf_extension('\ue87b'),
        gmf_face('\ue87c'),
        gmf_fast_forward('\ue01f'),
        gmf_fast_rewind('\ue020'),
        gmf_fastfood('\ue57a'),
        gmf_favorite('\ue87d'),
        gmf_favorite_border('\ue87e'),
        gmf_favorite_outline('\ue87e'),
        gmf_featured_play_list('\ue06d'),
        gmf_featured_video('\ue06e'),
        gmf_feedback('\ue87f'),
        gmf_festival('\uea68'),
        gmf_fiber_dvr('\ue05d'),
        gmf_fiber_manual_record('\ue061'),
        gmf_fiber_new('\ue05e'),
        gmf_fiber_pin('\ue06a'),
        gmf_fiber_smart_record('\ue062'),
        gmf_file_copy('\ue173'),
        gmf_file_download('\ue2c4'),
        gmf_file_download_done('\ue9aa'),
        gmf_file_present('\uea0e'),
        gmf_file_upload('\ue2c6'),
        gmf_filter('\ue3d3'),
        gmf_filter_1('\ue3d0'),
        gmf_filter_2('\ue3d1'),
        gmf_filter_3('\ue3d2'),
        gmf_filter_4('\ue3d4'),
        gmf_filter_5('\ue3d5'),
        gmf_filter_6('\ue3d6'),
        gmf_filter_7('\ue3d7'),
        gmf_filter_8('\ue3d8'),
        gmf_filter_9('\ue3d9'),
        gmf_filter_9_plus('\ue3da'),
        gmf_filter_b_and_w('\ue3db'),
        gmf_filter_center_focus('\ue3dc'),
        gmf_filter_drama('\ue3dd'),
        gmf_filter_frames('\ue3de'),
        gmf_filter_hdr('\ue3df'),
        gmf_filter_list('\ue152'),
        gmf_filter_list_alt('\ue94e'),
        gmf_filter_none('\ue3e0'),
        gmf_filter_tilt_shift('\ue3e2'),
        gmf_filter_vintage('\ue3e3'),
        gmf_find_in_page('\ue880'),
        gmf_find_replace('\ue881'),
        gmf_fingerprint('\ue90d'),
        gmf_fireplace('\uea43'),
        gmf_first_page('\ue5dc'),
        gmf_fit_screen('\uea10'),
        gmf_fitness_center('\ueb43'),
        gmf_flag('\ue153'),
        gmf_flare('\ue3e4'),
        gmf_flash_auto('\ue3e5'),
        gmf_flash_off('\ue3e6'),
        gmf_flash_on('\ue3e7'),
        gmf_flight('\ue539'),
        gmf_flight_land('\ue904'),
        gmf_flight_takeoff('\ue905'),
        gmf_flip('\ue3e8'),
        gmf_flip_camera_android('\uea37'),
        gmf_flip_camera_ios('\uea38'),
        gmf_flip_to_back('\ue882'),
        gmf_flip_to_front('\ue883'),
        gmf_folder('\ue2c7'),
        gmf_folder_open('\ue2c8'),
        gmf_folder_shared('\ue2c9'),
        gmf_folder_special('\ue617'),
        gmf_font_download('\ue167'),
        gmf_format_align_center('\ue234'),
        gmf_format_align_justify('\ue235'),
        gmf_format_align_left('\ue236'),
        gmf_format_align_right('\ue237'),
        gmf_format_bold('\ue238'),
        gmf_format_clear('\ue239'),
        gmf_format_color_fill('\ue23a'),
        gmf_format_color_reset('\ue23b'),
        gmf_format_color_text('\ue23c'),
        gmf_format_indent_decrease('\ue23d'),
        gmf_format_indent_increase('\ue23e'),
        gmf_format_italic('\ue23f'),
        gmf_format_line_spacing('\ue240'),
        gmf_format_list_bulleted('\ue241'),
        gmf_format_list_numbered('\ue242'),
        gmf_format_list_numbered_rtl('\ue267'),
        gmf_format_paint('\ue243'),
        gmf_format_quote('\ue244'),
        gmf_format_shapes('\ue25e'),
        gmf_format_size('\ue245'),
        gmf_format_strikethrough('\ue246'),
        gmf_format_textdirection_l_to_r('\ue247'),
        gmf_format_textdirection_r_to_l('\ue248'),
        gmf_format_underline('\ue249'),
        gmf_format_underlined('\ue249'),
        gmf_forum('\ue0bf'),
        gmf_forward('\ue154'),
        gmf_forward_10('\ue056'),
        gmf_forward_30('\ue057'),
        gmf_forward_5('\ue058'),
        gmf_free_breakfast('\ueb44'),
        gmf_fullscreen('\ue5d0'),
        gmf_fullscreen_exit('\ue5d1'),
        gmf_functions('\ue24a'),
        gmf_g_translate('\ue927'),
        gmf_gamepad('\ue30f'),
        gmf_games('\ue021'),
        gmf_gavel('\ue90e'),
        gmf_gesture('\ue155'),
        gmf_get_app('\ue884'),
        gmf_gif('\ue908'),
        gmf_goat('\udbff'),
        gmf_golf_course('\ueb45'),
        gmf_gps_fixed('\ue1b3'),
        gmf_gps_not_fixed('\ue1b4'),
        gmf_gps_off('\ue1b5'),
        gmf_grade('\ue885'),
        gmf_gradient('\ue3e9'),
        gmf_grain('\ue3ea'),
        gmf_graphic_eq('\ue1b8'),
        gmf_grid_off('\ue3eb'),
        gmf_grid_on('\ue3ec'),
        gmf_grid_view('\ue9b0'),
        gmf_group('\ue7ef'),
        gmf_group_add('\ue7f0'),
        gmf_group_work('\ue886'),
        gmf_hail('\ue9b1'),
        gmf_hardware('\uea59'),
        gmf_hd('\ue052'),
        gmf_hdr_off('\ue3ed'),
        gmf_hdr_on('\ue3ee'),
        gmf_hdr_strong('\ue3f1'),
        gmf_hdr_weak('\ue3f2'),
        gmf_headset('\ue310'),
        gmf_headset_mic('\ue311'),
        gmf_headset_off('\ue33a'),
        gmf_healing('\ue3f3'),
        gmf_hearing('\ue023'),
        gmf_height('\uea16'),
        gmf_help('\ue887'),
        gmf_help_outline('\ue8fd'),
        gmf_high_quality('\ue024'),
        gmf_highlight('\ue25f'),
        gmf_highlight_off('\ue888'),
        gmf_highlight_remove('\ue888'),
        gmf_history('\ue889'),
        gmf_home('\ue88a'),
        gmf_home_filled('\ue9b2'),
        gmf_home_work('\uea09'),
        gmf_horizontal_split('\ue947'),
        gmf_hot_tub('\ueb46'),
        gmf_hotel('\ue53a'),
        gmf_hourglass_empty('\ue88b'),
        gmf_hourglass_full('\ue88c'),
        gmf_house('\uea44'),
        gmf_how_to_reg('\ue174'),
        gmf_how_to_vote('\ue175'),
        gmf_http('\ue902'),
        gmf_https('\ue88d'),
        gmf_icecream('\uea69'),
        gmf_image('\ue3f4'),
        gmf_image_aspect_ratio('\ue3f5'),
        gmf_image_search('\ue43f'),
        gmf_imagesearch_roller('\ue9b4'),
        gmf_import_contacts('\ue0e0'),
        gmf_import_export('\ue0c3'),
        gmf_important_devices('\ue912'),
        gmf_inbox('\ue156'),
        gmf_indeterminate_check_box('\ue909'),
        gmf_info('\ue88e'),
        gmf_info_outline('\ue88f'),
        gmf_input('\ue890'),
        gmf_insert_chart('\ue24b'),
        gmf_insert_chart_outlined('\ue26a'),
        gmf_insert_comment('\ue24c'),
        gmf_insert_drive_file('\ue24d'),
        gmf_insert_emoticon('\ue24e'),
        gmf_insert_invitation('\ue24f'),
        gmf_insert_link('\ue250'),
        gmf_insert_photo('\ue251'),
        gmf_inventory('\ue179'),
        gmf_invert_colors('\ue891'),
        gmf_invert_colors_off('\ue0c4'),
        gmf_invert_colors_on('\ue891'),
        gmf_iso('\ue3f6'),
        gmf_keyboard('\ue312'),
        gmf_keyboard_arrow_down('\ue313'),
        gmf_keyboard_arrow_left('\ue314'),
        gmf_keyboard_arrow_right('\ue315'),
        gmf_keyboard_arrow_up('\ue316'),
        gmf_keyboard_backspace('\ue317'),
        gmf_keyboard_capslock('\ue318'),
        gmf_keyboard_control('\ue5d3'),
        gmf_keyboard_hide('\ue31a'),
        gmf_keyboard_return('\ue31b'),
        gmf_keyboard_tab('\ue31c'),
        gmf_keyboard_voice('\ue31d'),
        gmf_king_bed('\uea45'),
        gmf_kitchen('\ueb47'),
        gmf_label('\ue892'),
        gmf_label_important('\ue937'),
        gmf_label_important_outline('\ue948'),
        gmf_label_off('\ue9b6'),
        gmf_label_outline('\ue893'),
        gmf_landscape('\ue3f7'),
        gmf_language('\ue894'),
        gmf_laptop('\ue31e'),
        gmf_laptop_chromebook('\ue31f'),
        gmf_laptop_mac('\ue320'),
        gmf_laptop_windows('\ue321'),
        gmf_last_page('\ue5dd'),
        gmf_launch('\ue895'),
        gmf_layers('\ue53b'),
        gmf_layers_clear('\ue53c'),
        gmf_leak_add('\ue3f8'),
        gmf_leak_remove('\ue3f9'),
        gmf_lens('\ue3fa'),
        gmf_library_add('\ue02e'),
        gmf_library_add_check('\ue9b7'),
        gmf_library_books('\ue02f'),
        gmf_library_music('\ue030'),
        gmf_lightbulb('\ue0f0'),
        gmf_lightbulb_outline('\ue90f'),
        gmf_line_style('\ue919'),
        gmf_line_weight('\ue91a'),
        gmf_linear_scale('\ue260'),
        gmf_link('\ue157'),
        gmf_link_off('\ue16f'),
        gmf_linked_camera('\ue438'),
        gmf_liquor('\uea60'),
        gmf_list('\ue896'),
        gmf_list_alt('\ue0ee'),
        gmf_live_help('\ue0c6'),
        gmf_live_tv('\ue639'),
        gmf_local_activity('\ue53f'),
        gmf_local_airport('\ue53d'),
        gmf_local_atm('\ue53e'),
        gmf_local_attraction('\ue53f'),
        gmf_local_bar('\ue540'),
        gmf_local_cafe('\ue541'),
        gmf_local_car_wash('\ue542'),
        gmf_local_convenience_store('\ue543'),
        gmf_local_dining('\ue556'),
        gmf_local_drink('\ue544'),
        gmf_local_florist('\ue545'),
        gmf_local_gas_station('\ue546'),
        gmf_local_grocery_store('\ue547'),
        gmf_local_hospital('\ue548'),
        gmf_local_hotel('\ue549'),
        gmf_local_laundry_service('\ue54a'),
        gmf_local_library('\ue54b'),
        gmf_local_mall('\ue54c'),
        gmf_local_movies('\ue54d'),
        gmf_local_offer('\ue54e'),
        gmf_local_parking('\ue54f'),
        gmf_local_pharmacy('\ue550'),
        gmf_local_phone('\ue551'),
        gmf_local_pizza('\ue552'),
        gmf_local_play('\ue553'),
        gmf_local_post_office('\ue554'),
        gmf_local_print_shop('\ue555'),
        gmf_local_printshop('\ue555'),
        gmf_local_restaurant('\ue556'),
        gmf_local_see('\ue557'),
        gmf_local_shipping('\ue558'),
        gmf_local_taxi('\ue559'),
        gmf_location_city('\ue7f1'),
        gmf_location_disabled('\ue1b6'),
        gmf_location_history('\ue55a'),
        gmf_location_off('\ue0c7'),
        gmf_location_on('\ue0c8'),
        gmf_location_searching('\ue1b7'),
        gmf_lock('\ue897'),
        gmf_lock_open('\ue898'),
        gmf_lock_outline('\ue899'),
        gmf_logout('\ue9ba'),
        gmf_looks('\ue3fc'),
        gmf_looks_3('\ue3fb'),
        gmf_looks_4('\ue3fd'),
        gmf_looks_5('\ue3fe'),
        gmf_looks_6('\ue3ff'),
        gmf_looks_one('\ue400'),
        gmf_looks_two('\ue401'),
        gmf_loop('\ue028'),
        gmf_loupe('\ue402'),
        gmf_low_priority('\ue16d'),
        gmf_loyalty('\ue89a'),
        gmf_lunch_dining('\uea61'),
        gmf_mail('\ue158'),
        gmf_mail_outline('\ue0e1'),
        gmf_map('\ue55b'),
        gmf_margin('\ue9bb'),
        gmf_mark_as_unread('\ue9bc'),
        gmf_markunread('\ue159'),
        gmf_markunread_mailbox('\ue89b'),
        gmf_maximize('\ue930'),
        gmf_meeting_room('\ueb4f'),
        gmf_memory('\ue322'),
        gmf_menu('\ue5d2'),
        gmf_menu_book('\uea19'),
        gmf_menu_open('\ue9bd'),
        gmf_merge_type('\ue252'),
        gmf_message('\ue0c9'),
        gmf_messenger('\ue0ca'),
        gmf_messenger_outline('\ue0cb'),
        gmf_mic('\ue029'),
        gmf_mic_none('\ue02a'),
        gmf_mic_off('\ue02b'),
        gmf_minimize('\ue931'),
        gmf_missed_video_call('\ue073'),
        gmf_mms('\ue618'),
        gmf_mobile_friendly('\ue200'),
        gmf_mobile_off('\ue201'),
        gmf_mobile_screen_share('\ue0e7'),
        gmf_mode_comment('\ue253'),
        gmf_mode_edit('\ue254'),
        gmf_monetization_on('\ue263'),
        gmf_money('\ue57d'),
        gmf_money_off('\ue25c'),
        gmf_monochrome_photos('\ue403'),
        gmf_mood('\ue7f2'),
        gmf_mood_bad('\ue7f3'),
        gmf_more('\ue619'),
        gmf_more_horiz('\ue5d3'),
        gmf_more_vert('\ue5d4'),
        gmf_motorcycle('\ue91b'),
        gmf_mouse('\ue323'),
        gmf_move_to_inbox('\ue168'),
        gmf_movie('\ue02c'),
        gmf_movie_creation('\ue404'),
        gmf_movie_filter('\ue43a'),
        gmf_mp('\ue9c3'),
        gmf_multiline_chart('\ue6df'),
        gmf_multitrack_audio('\ue1b8'),
        gmf_museum('\uea36'),
        gmf_music_note('\ue405'),
        gmf_music_off('\ue440'),
        gmf_music_video('\ue063'),
        gmf_my_library_add('\ue02e'),
        gmf_my_library_books('\ue02f'),
        gmf_my_library_music('\ue030'),
        gmf_my_location('\ue55c'),
        gmf_nature('\ue406'),
        gmf_nature_people('\ue407'),
        gmf_navigate_before('\ue408'),
        gmf_navigate_next('\ue409'),
        gmf_navigation('\ue55d'),
        gmf_near_me('\ue569'),
        gmf_network_cell('\ue1b9'),
        gmf_network_check('\ue640'),
        gmf_network_locked('\ue61a'),
        gmf_network_wifi('\ue1ba'),
        gmf_new_releases('\ue031'),
        gmf_next_week('\ue16a'),
        gmf_nfc('\ue1bb'),
        gmf_nightlife('\uea62'),
        gmf_nights_stay('\uea46'),
        gmf_no_encryption('\ue641'),
        gmf_no_meeting_room('\ueb4e'),
        gmf_no_sim('\ue0cc'),
        gmf_not_interested('\ue033'),
        gmf_not_listed_location('\ue575'),
        gmf_note('\ue06f'),
        gmf_note_add('\ue89c'),
        gmf_notes('\ue26c'),
        gmf_notification_important('\ue004'),
        gmf_notifications('\ue7f4'),
        gmf_notifications_active('\ue7f7'),
        gmf_notifications_none('\ue7f5'),
        gmf_notifications_off('\ue7f6'),
        gmf_notifications_on('\ue7f7'),
        gmf_notifications_paused('\ue7f8'),
        gmf_now_wallpaper('\ue1bc'),
        gmf_now_widgets('\ue1bd'),
        gmf_offline_bolt('\ue932'),
        gmf_offline_pin('\ue90a'),
        gmf_offline_share('\ue9c5'),
        gmf_ondemand_video('\ue63a'),
        gmf_opacity('\ue91c'),
        gmf_open_in_browser('\ue89d'),
        gmf_open_in_new('\ue89e'),
        gmf_open_with('\ue89f'),
        gmf_outdoor_grill('\uea47'),
        gmf_outlined_flag('\ue16e'),
        gmf_padding('\ue9c8'),
        gmf_pages('\ue7f9'),
        gmf_pageview('\ue8a0'),
        gmf_palette('\ue40a'),
        gmf_pan_tool('\ue925'),
        gmf_panorama('\ue40b'),
        gmf_panorama_fish_eye('\ue40c'),
        gmf_panorama_fisheye('\ue40c'),
        gmf_panorama_horizontal('\ue40d'),
        gmf_panorama_photosphere('\ue9c9'),
        gmf_panorama_photosphere_select('\ue9ca'),
        gmf_panorama_vertical('\ue40e'),
        gmf_panorama_wide_angle('\ue40f'),
        gmf_park('\uea63'),
        gmf_party_mode('\ue7fa'),
        gmf_pause('\ue034'),
        gmf_pause_circle_filled('\ue035'),
        gmf_pause_circle_outline('\ue036'),
        gmf_pause_presentation('\ue0ea'),
        gmf_payment('\ue8a1'),
        gmf_people('\ue7fb'),
        gmf_people_alt('\uea21'),
        gmf_people_outline('\ue7fc'),
        gmf_perm_camera_mic('\ue8a2'),
        gmf_perm_contact_cal('\ue8a3'),
        gmf_perm_contact_calendar('\ue8a3'),
        gmf_perm_data_setting('\ue8a4'),
        gmf_perm_device_info('\ue8a5'),
        gmf_perm_device_information('\ue8a5'),
        gmf_perm_identity('\ue8a6'),
        gmf_perm_media('\ue8a7'),
        gmf_perm_phone_msg('\ue8a8'),
        gmf_perm_scan_wifi('\ue8a9'),
        gmf_person('\ue7fd'),
        gmf_person_add('\ue7fe'),
        gmf_person_add_disabled('\ue9cb'),
        gmf_person_outline('\ue7ff'),
        gmf_person_pin('\ue55a'),
        gmf_person_pin_circle('\ue56a'),
        gmf_personal_video('\ue63b'),
        gmf_pets('\ue91d'),
        gmf_phone('\ue0cd'),
        gmf_phone_android('\ue324'),
        gmf_phone_bluetooth_speaker('\ue61b'),
        gmf_phone_callback('\ue649'),
        gmf_phone_disabled('\ue9cc'),
        gmf_phone_enabled('\ue9cd'),
        gmf_phone_forwarded('\ue61c'),
        gmf_phone_in_talk('\ue61d'),
        gmf_phone_iphone('\ue325'),
        gmf_phone_locked('\ue61e'),
        gmf_phone_missed('\ue61f'),
        gmf_phone_paused('\ue620'),
        gmf_phonelink('\ue326'),
        gmf_phonelink_erase('\ue0db'),
        gmf_phonelink_lock('\ue0dc'),
        gmf_phonelink_off('\ue327'),
        gmf_phonelink_ring('\ue0dd'),
        gmf_phonelink_setup('\ue0de'),
        gmf_photo('\ue410'),
        gmf_photo_album('\ue411'),
        gmf_photo_camera('\ue412'),
        gmf_photo_filter('\ue43b'),
        gmf_photo_library('\ue413'),
        gmf_photo_size_select_actual('\ue432'),
        gmf_photo_size_select_large('\ue433'),
        gmf_photo_size_select_small('\ue434'),
        gmf_picture_as_pdf('\ue415'),
        gmf_picture_in_picture('\ue8aa'),
        gmf_picture_in_picture_alt('\ue911'),
        gmf_pie_chart('\ue6c4'),
        gmf_pie_chart_outlined('\ue6c5'),
        gmf_pin_drop('\ue55e'),
        gmf_pivot_table_chart('\ue9ce'),
        gmf_place('\ue55f'),
        gmf_play_arrow('\ue037'),
        gmf_play_circle_fill('\ue038'),
        gmf_play_circle_filled('\ue038'),
        gmf_play_circle_outline('\ue039'),
        gmf_play_for_work('\ue906'),
        gmf_playlist_add('\ue03b'),
        gmf_playlist_add_check('\ue065'),
        gmf_playlist_play('\ue05f'),
        gmf_plus_one('\ue800'),
        gmf_policy('\uea17'),
        gmf_poll('\ue801'),
        gmf_polymer('\ue8ab'),
        gmf_pool('\ueb48'),
        gmf_portable_wifi_off('\ue0ce'),
        gmf_portrait('\ue416'),
        gmf_post_add('\uea20'),
        gmf_power('\ue63c'),
        gmf_power_input('\ue336'),
        gmf_power_off('\ue646'),
        gmf_power_settings_new('\ue8ac'),
        gmf_pregnant_woman('\ue91e'),
        gmf_present_to_all('\ue0df'),
        gmf_print('\ue8ad'),
        gmf_print_disabled('\ue9cf'),
        gmf_priority_high('\ue645'),
        gmf_public('\ue80b'),
        gmf_publish('\ue255'),
        gmf_query_builder('\ue8ae'),
        gmf_question_answer('\ue8af'),
        gmf_queue('\ue03c'),
        gmf_queue_music('\ue03d'),
        gmf_queue_play_next('\ue066'),
        gmf_quick_contacts_dialer('\ue0cf'),
        gmf_quick_contacts_mail('\ue0d0'),
        gmf_radio('\ue03e'),
        gmf_radio_button_checked('\ue837'),
        gmf_radio_button_off('\ue836'),
        gmf_radio_button_on('\ue837'),
        gmf_radio_button_unchecked('\ue836'),
        gmf_railway_alert('\ue9d1'),
        gmf_ramen_dining('\uea64'),
        gmf_rate_review('\ue560'),
        gmf_receipt('\ue8b0'),
        gmf_recent_actors('\ue03f'),
        gmf_recommend('\ue9d2'),
        gmf_record_voice_over('\ue91f'),
        gmf_redeem('\ue8b1'),
        gmf_redo('\ue15a'),
        gmf_refresh('\ue5d5'),
        gmf_remove('\ue15b'),
        gmf_remove_circle('\ue15c'),
        gmf_remove_circle_outline('\ue15d'),
        gmf_remove_done('\ue9d3'),
        gmf_remove_from_queue('\ue067'),
        gmf_remove_moderator('\ue9d4'),
        gmf_remove_red_eye('\ue417'),
        gmf_remove_shopping_cart('\ue928'),
        gmf_reorder('\ue8fe'),
        gmf_repeat('\ue040'),
        gmf_repeat_on('\ue9d6'),
        gmf_repeat_one('\ue041'),
        gmf_repeat_one_on('\ue9d7'),
        gmf_replay('\ue042'),
        gmf_replay_10('\ue059'),
        gmf_replay_30('\ue05a'),
        gmf_replay_5('\ue05b'),
        gmf_replay_circle_filled('\ue9d8'),
        gmf_reply('\ue15e'),
        gmf_reply_all('\ue15f'),
        gmf_report('\ue160'),
        gmf_report_off('\ue170'),
        gmf_report_problem('\ue8b2'),
        gmf_reset_tv('\ue9d9'),
        gmf_restaurant('\ue56c'),
        gmf_restaurant_menu('\ue561'),
        gmf_restore('\ue8b3'),
        gmf_restore_from_trash('\ue938'),
        gmf_restore_page('\ue929'),
        gmf_ring_volume('\ue0d1'),
        gmf_room('\ue8b4'),
        gmf_room_service('\ueb49'),
        gmf_rotate_90_degrees_ccw('\ue418'),
        gmf_rotate_left('\ue419'),
        gmf_rotate_right('\ue41a'),
        gmf_rounded_corner('\ue920'),
        gmf_router('\ue328'),
        gmf_rowing('\ue921'),
        gmf_rss_feed('\ue0e5'),
        gmf_rtt('\ue9ad'),
        gmf_rv_hookup('\ue642'),
        gmf_satellite('\ue562'),
        gmf_save('\ue161'),
        gmf_save_alt('\ue171'),
        gmf_saved_search('\uea11'),
        gmf_scanner('\ue329'),
        gmf_scatter_plot('\ue268'),
        gmf_schedule('\ue8b5'),
        gmf_schedule_send('\uea0a'),
        gmf_school('\ue80c'),
        gmf_score('\ue269'),
        gmf_screen_lock_landscape('\ue1be'),
        gmf_screen_lock_portrait('\ue1bf'),
        gmf_screen_lock_rotation('\ue1c0'),
        gmf_screen_rotation('\ue1c1'),
        gmf_screen_share('\ue0e2'),
        gmf_sd('\ue9dd'),
        gmf_sd_card('\ue623'),
        gmf_sd_storage('\ue1c2'),
        gmf_search('\ue8b6'),
        gmf_security('\ue32a'),
        gmf_segment('\ue94b'),
        gmf_select_all('\ue162'),
        gmf_send('\ue163'),
        gmf_send_and_archive('\uea0c'),
        gmf_sentiment_dissatisfied('\ue811'),
        gmf_sentiment_neutral('\ue812'),
        gmf_sentiment_satisfied('\ue813'),
        gmf_sentiment_satisfied_alt('\ue0ed'),
        gmf_sentiment_very_dissatisfied('\ue814'),
        gmf_sentiment_very_satisfied('\ue815'),
        gmf_settings('\ue8b8'),
        gmf_settings_applications('\ue8b9'),
        gmf_settings_backup_restore('\ue8ba'),
        gmf_settings_bluetooth('\ue8bb'),
        gmf_settings_brightness('\ue8bd'),
        gmf_settings_cell('\ue8bc'),
        gmf_settings_display('\ue8bd'),
        gmf_settings_ethernet('\ue8be'),
        gmf_settings_input_antenna('\ue8bf'),
        gmf_settings_input_component('\ue8c0'),
        gmf_settings_input_composite('\ue8c1'),
        gmf_settings_input_hdmi('\ue8c2'),
        gmf_settings_input_svideo('\ue8c3'),
        gmf_settings_overscan('\ue8c4'),
        gmf_settings_phone('\ue8c5'),
        gmf_settings_power('\ue8c6'),
        gmf_settings_remote('\ue8c7'),
        gmf_settings_system_daydream('\ue1c3'),
        gmf_settings_voice('\ue8c8'),
        gmf_share('\ue80d'),
        gmf_shield('\ue9e0'),
        gmf_shop('\ue8c9'),
        gmf_shop_two('\ue8ca'),
        gmf_shopping_basket('\ue8cb'),
        gmf_shopping_cart('\ue8cc'),
        gmf_short_text('\ue261'),
        gmf_show_chart('\ue6e1'),
        gmf_shuffle('\ue043'),
        gmf_shuffle_on('\ue9e1'),
        gmf_shutter_speed('\ue43d'),
        gmf_signal_cellular_4_bar('\ue1c8'),
        gmf_signal_cellular_alt('\ue202'),
        gmf_signal_cellular_connected_no_internet_4_bar('\ue1cd'),
        gmf_signal_cellular_no_sim('\ue1ce'),
        gmf_signal_cellular_null('\ue1cf'),
        gmf_signal_cellular_off('\ue1d0'),
        gmf_signal_wifi_4_bar('\ue1d8'),
        gmf_signal_wifi_4_bar_lock('\ue1d9'),
        gmf_signal_wifi_off('\ue1da'),
        gmf_sim_card('\ue32b'),
        gmf_sim_card_alert('\ue624'),
        gmf_single_bed('\uea48'),
        gmf_skip_next('\ue044'),
        gmf_skip_previous('\ue045'),
        gmf_slideshow('\ue41b'),
        gmf_slow_motion_video('\ue068'),
        gmf_smartphone('\ue32c'),
        gmf_smoke_free('\ueb4a'),
        gmf_smoking_rooms('\ueb4b'),
        gmf_sms('\ue625'),
        gmf_sms_failed('\ue626'),
        gmf_snooze('\ue046'),
        gmf_sort('\ue164'),
        gmf_sort_by_alpha('\ue053'),
        gmf_spa('\ueb4c'),
        gmf_space_bar('\ue256'),
        gmf_speaker('\ue32d'),
        gmf_speaker_group('\ue32e'),
        gmf_speaker_notes('\ue8cd'),
        gmf_speaker_notes_off('\ue92a'),
        gmf_speaker_phone('\ue0d2'),
        gmf_speed('\ue9e4'),
        gmf_spellcheck('\ue8ce'),
        gmf_sports('\uea30'),
        gmf_sports_baseball('\uea51'),
        gmf_sports_basketball('\uea26'),
        gmf_sports_cricket('\uea27'),
        gmf_sports_esports('\uea28'),
        gmf_sports_football('\uea29'),
        gmf_sports_golf('\uea2a'),
        gmf_sports_handball('\uea33'),
        gmf_sports_hockey('\uea2b'),
        gmf_sports_kabaddi('\uea34'),
        gmf_sports_mma('\uea2c'),
        gmf_sports_motorsports('\uea2d'),
        gmf_sports_rugby('\uea2e'),
        gmf_sports_soccer('\uea2f'),
        gmf_sports_tennis('\uea32'),
        gmf_sports_volleyball('\uea31'),
        gmf_square_foot('\uea49'),
        gmf_stacked_bar_chart('\ue9e6'),
        gmf_star('\ue838'),
        gmf_star_border('\ue83a'),
        gmf_star_half('\ue839'),
        gmf_star_outline('\ue83a'),
        gmf_stars('\ue8d0'),
        gmf_stay_current_landscape('\ue0d3'),
        gmf_stay_current_portrait('\ue0d4'),
        gmf_stay_primary_landscape('\ue0d5'),
        gmf_stay_primary_portrait('\ue0d6'),
        gmf_stop('\ue047'),
        gmf_stop_screen_share('\ue0e3'),
        gmf_storage('\ue1db'),
        gmf_store('\ue8d1'),
        gmf_store_mall_directory('\ue563'),
        gmf_storefront('\uea12'),
        gmf_straighten('\ue41c'),
        gmf_stream('\ue9e9'),
        gmf_streetview('\ue56e'),
        gmf_strikethrough_s('\ue257'),
        gmf_style('\ue41d'),
        gmf_subdirectory_arrow_left('\ue5d9'),
        gmf_subdirectory_arrow_right('\ue5da'),
        gmf_subject('\ue8d2'),
        gmf_subscriptions('\ue064'),
        gmf_subtitles('\ue048'),
        gmf_subway('\ue56f'),
        gmf_supervised_user_circle('\ue939'),
        gmf_supervisor_account('\ue8d3'),
        gmf_surround_sound('\ue049'),
        gmf_swap_calls('\ue0d7'),
        gmf_swap_horiz('\ue8d4'),
        gmf_swap_horizontal_circle('\ue933'),
        gmf_swap_vert('\ue8d5'),
        gmf_swap_vert_circle('\ue8d6'),
        gmf_swap_vertical_circle('\ue8d6'),
        gmf_swipe('\ue9ec'),
        gmf_switch_account('\ue9ed'),
        gmf_switch_camera('\ue41e'),
        gmf_switch_video('\ue41f'),
        gmf_sync('\ue627'),
        gmf_sync_alt('\uea18'),
        gmf_sync_disabled('\ue628'),
        gmf_sync_problem('\ue629'),
        gmf_system_update('\ue62a'),
        gmf_system_update_alt('\ue8d7'),
        gmf_system_update_tv('\ue8d7'),
        gmf_tab('\ue8d8'),
        gmf_tab_unselected('\ue8d9'),
        gmf_table_chart('\ue265'),
        gmf_tablet('\ue32f'),
        gmf_tablet_android('\ue330'),
        gmf_tablet_mac('\ue331'),
        gmf_tag('\ue9ef'),
        gmf_tag_faces('\ue420'),
        gmf_takeout_dining('\uea74'),
        gmf_tap_and_play('\ue62b'),
        gmf_terrain('\ue564'),
        gmf_text_fields('\ue262'),
        gmf_text_format('\ue165'),
        gmf_text_rotate_up('\ue93a'),
        gmf_text_rotate_vertical('\ue93b'),
        gmf_text_rotation_angledown('\ue93c'),
        gmf_text_rotation_angleup('\ue93d'),
        gmf_text_rotation_down('\ue93e'),
        gmf_text_rotation_none('\ue93f'),
        gmf_textsms('\ue0d8'),
        gmf_texture('\ue421'),
        gmf_theater_comedy('\uea66'),
        gmf_theaters('\ue8da'),
        gmf_thumb_down('\ue8db'),
        gmf_thumb_down_alt('\ue816'),
        gmf_thumb_down_off_alt('\ue9f2'),
        gmf_thumb_up('\ue8dc'),
        gmf_thumb_up_alt('\ue817'),
        gmf_thumb_up_off_alt('\ue9f3'),
        gmf_thumbs_up_down('\ue8dd'),
        gmf_time_to_leave('\ue62c'),
        gmf_timelapse('\ue422'),
        gmf_timeline('\ue922'),
        gmf_timer('\ue425'),
        gmf_timer_10('\ue423'),
        gmf_timer_3('\ue424'),
        gmf_timer_off('\ue426'),
        gmf_title('\ue264'),
        gmf_toc('\ue8de'),
        gmf_today('\ue8df'),
        gmf_toggle_off('\ue9f5'),
        gmf_toggle_on('\ue9f6'),
        gmf_toll('\ue8e0'),
        gmf_tonality('\ue427'),
        gmf_touch_app('\ue913'),
        gmf_toys('\ue332'),
        gmf_track_changes('\ue8e1'),
        gmf_traffic('\ue565'),
        gmf_train('\ue570'),
        gmf_tram('\ue571'),
        gmf_transfer_within_a_station('\ue572'),
        gmf_transform('\ue428'),
        gmf_transit_enterexit('\ue579'),
        gmf_translate('\ue8e2'),
        gmf_trending_down('\ue8e3'),
        gmf_trending_flat('\ue8e4'),
        gmf_trending_neutral('\ue8e4'),
        gmf_trending_up('\ue8e5'),
        gmf_trip_origin('\ue57b'),
        gmf_tune('\ue429'),
        gmf_turned_in('\ue8e6'),
        gmf_turned_in_not('\ue8e7'),
        gmf_tv('\ue333'),
        gmf_tv_off('\ue647'),
        gmf_two_wheeler('\ue9f9'),
        gmf_unarchive('\ue169'),
        gmf_undo('\ue166'),
        gmf_unfold_less('\ue5d6'),
        gmf_unfold_more('\ue5d7'),
        gmf_unsubscribe('\ue0eb'),
        gmf_update('\ue923'),
        gmf_upload_file('\ue9fc'),
        gmf_usb('\ue1e0'),
        gmf_verified_user('\ue8e8'),
        gmf_vertical_align_bottom('\ue258'),
        gmf_vertical_align_center('\ue259'),
        gmf_vertical_align_top('\ue25a'),
        gmf_vertical_split('\ue949'),
        gmf_vibration('\ue62d'),
        gmf_video_call('\ue070'),
        gmf_video_collection('\ue04a'),
        gmf_video_label('\ue071'),
        gmf_video_library('\ue04a'),
        gmf_videocam('\ue04b'),
        gmf_videocam_off('\ue04c'),
        gmf_videogame_asset('\ue338'),
        gmf_view_agenda('\ue8e9'),
        gmf_view_array('\ue8ea'),
        gmf_view_carousel('\ue8eb'),
        gmf_view_column('\ue8ec'),
        gmf_view_comfortable('\ue42a'),
        gmf_view_comfy('\ue42a'),
        gmf_view_compact('\ue42b'),
        gmf_view_day('\ue8ed'),
        gmf_view_headline('\ue8ee'),
        gmf_view_in_ar('\ue9fe'),
        gmf_view_list('\ue8ef'),
        gmf_view_module('\ue8f0'),
        gmf_view_quilt('\ue8f1'),
        gmf_view_stream('\ue8f2'),
        gmf_view_week('\ue8f3'),
        gmf_vignette('\ue435'),
        gmf_visibility('\ue8f4'),
        gmf_visibility_off('\ue8f5'),
        gmf_voice_chat('\ue62e'),
        gmf_voice_over_off('\ue94a'),
        gmf_voicemail('\ue0d9'),
        gmf_volume_down('\ue04d'),
        gmf_volume_mute('\ue04e'),
        gmf_volume_off('\ue04f'),
        gmf_volume_up('\ue050'),
        gmf_volunteer_activism('\uea70'),
        gmf_vpn_key('\ue0da'),
        gmf_vpn_lock('\ue62f'),
        gmf_wallet_giftcard('\ue8f6'),
        gmf_wallet_membership('\ue8f7'),
        gmf_wallet_travel('\ue8f8'),
        gmf_wallpaper('\ue1bc'),
        gmf_warning('\ue002'),
        gmf_watch('\ue334'),
        gmf_watch_later('\ue924'),
        gmf_waterfall_chart('\uea00'),
        gmf_waves('\ue176'),
        gmf_wb_auto('\ue42c'),
        gmf_wb_cloudy('\ue42d'),
        gmf_wb_incandescent('\ue42e'),
        gmf_wb_iridescent('\ue436'),
        gmf_wb_shade('\uea01'),
        gmf_wb_sunny('\ue430'),
        gmf_wb_twighlight('\uea02'),
        gmf_wc('\ue63d'),
        gmf_web('\ue051'),
        gmf_web_asset('\ue069'),
        gmf_weekend('\ue16b'),
        gmf_whatshot('\ue80e'),
        gmf_where_to_vote('\ue177'),
        gmf_widgets('\ue1bd'),
        gmf_wifi('\ue63e'),
        gmf_wifi_lock('\ue1e1'),
        gmf_wifi_off('\ue648'),
        gmf_wifi_tethering('\ue1e2'),
        gmf_work('\ue8f9'),
        gmf_work_off('\ue942'),
        gmf_work_outline('\ue943'),
        gmf_workspaces_filled('\uea0d'),
        gmf_workspaces_outline('\uea0f'),
        gmf_wrap_text('\ue25b'),
        gmf_youtube_searched_for('\ue8fa'),
        gmf_zoom_in('\ue8ff'),
        gmf_zoom_out('\ue900'),
        gmf_zoom_out_map('\ue56b');

        override val typeface: ITypeface by lazy { MaterialDesignDx }
    }
}